# rssh-monitor.pl
# Test a host by attempting to SSH into it

sub get_rssh_status
{
# Run the SSH command
&foreign_require("proc", "proc-lib.pl");
local ($fh, $fpid) = &proc::pty_process_exec(
	"ssh ".quotemeta($_[0]->{'ruser'})."\@".
	       quotemeta($_[0]->{'host'})." echo ok");
local ($out, $wrong_password, $connect_failed);
while(1) {
	local $rv = &wait_for($fh, "password:", "yes\\/no", "(^|\\n)\\s*Permission denied.*\n", "ssh: connect.*\n", ".*\n");
	$out .= $wait_for_input;
	if ($rv == 0) {
		syswrite($fh, "$_[0]->{'rpass'}\n");
		}
	elsif ($rv == 1) {
		syswrite($fh, "yes\n");
		}
	elsif ($rv == 2) {
		$wrong_password++;
		last;
		}
	elsif ($rv == 3) {
		$connect_failed++;
		}
	elsif ($rv < 0) {
		last;
		}
	}
close($fh);
kill('TERM', $fpid);
local $got = waitpid($fpid, 0);
print STDERR "got : $out";
if ($wrong_password) {
	return { 'up' => 0,
		 'desc' => $text{'rssh_wrongpass'} };
	}
if ($connect_failed) {
	return { 'up' => 0,
		 'desc' => $text{'rssh_failed'} };
	}
if ($?) {
	return { 'up' => 0,
		 'desc' => $text{'rssh_error'} };
	}
return { 'up' => 1 };

}

sub show_rssh_dialog
{
print &ui_table_row($text{'rssh_host'},
		    &ui_textbox("host", $_[0]->{'host'}, 50), 3);

print &ui_table_row($text{'rssh_ruser'},
		    &ui_textbox("ruser", $_[0]->{'ruser'}, 50), 3);

print &ui_table_row($text{'rssh_rpass'},
		    &ui_opt_textbox("rpass", $_[0]->{'rpass'}, 30,
				    $text{'rssh_nopass'}), 3);
}

sub parse_rssh_dialog
{
&has_command("ssh") || &error($text{'rssh_ecmd'});
&foreign_installed("proc") || &error($text{'rssh_eproc'});
$in{'host'} =~ /^[a-z0-9\.\-\_]+$/i || &error($text{'rssh_ehost'});
$_[0]->{'host'} = $in{'host'};
$in{'ruser_def'} || $in{'ruser'} =~ /\S/ || &error($text{'rssh_eruser'});
$_[0]->{'ruser'} = $in{'ruser_def'} ? undef : $in{'ruser'};
$_[0]->{'rpass'} = $in{'rpass_def'} ? undef : $in{'rpass'};
}

